@@ -74,10 +74,6 @@ class SimpCityCrawler:
                 pass
             else:
                 title = title_block.text
-                if self.include_id:
-                    titlep2 = url.name
-                    titlep2 = [s for s in titlep2 if "." in s][-1]
-                    title = title + " - " + titlep2
                 title = await make_title_safe(title.replace(r"\n", "").strip())
 
             content_links = []
@@ -204,13 +200,15 @@ class SimpCityCrawler:
                         next_page = domain / next_page[1:]
                     next_page = URL(next_page)
                     title = await self.parse_thread(session, next_page, cascade, title)
-
-            if self.output_last[0]:
-                if 'post-' in url.raw_name:
-                    last_post_url = url.parent / post_num_str
-                else:
-                    last_post_url = url / post_num_str
-                await write_last_post_file(self.output_last[1], str(last_post_url))
+            else:
+                if self.output_last[0]:
+                    if 'page-' in url.raw_name:
+                        last_post_url = url.parent / post_num_str
+                    elif 'post-' in url.raw_name:
+                        last_post_url = url.parent / post_num_str
+                    else:
+                        last_post_url = url / post_num_str
+                    await write_last_post_file(self.output_last[1], str(last_post_url))
 
             return
 
